package com.fs.quartz.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.scheduling.quartz.SchedulerFactoryBean;
import org.springframework.transaction.PlatformTransactionManager;

import javax.sql.DataSource;
import java.util.Properties;

/**
 * 定时任务配置
 * 

 */
@Configuration
public class ScheduleConfig {

    @Autowired
    private DataSource dataSource; // 确保注入主数据源

    @Bean
    public SchedulerFactoryBean schedulerFactoryBean() {
        SchedulerFactoryBean factory = new SchedulerFactoryBean();

        // 关键修复：显式设置数据源和事务管理器
        factory.setDataSource(dataSource);
        factory.setTransactionManager(transactionManager());

        // 其他配置保持不变
        factory.setSchedulerName("FsScheduler");
        factory.setStartupDelay(10);
        factory.setApplicationContextSchedulerContextKey("applicationContext");
        return factory;
    }

    @Bean
    public PlatformTransactionManager transactionManager() {
        return new DataSourceTransactionManager(dataSource);
    }
}
